Data

Struct Data 

pub struct Data {
Show 18 fields pub joint_data: Vec<JointDataWrapper>, pub joint_placements: Vec<SE3>, pub frame_placements: Vec<SE3>, pub local_joint_placements: Vec<SE3>, pub joint_velocities: Vec<SpatialMotion>, pub world_joint_velocities: Vec<SpatialMotion>, pub joint_accelerations: Vec<SpatialMotion>, pub joint_accelerations_gravity_field: Vec<SpatialMotion>, pub world_accelerations_gravity_field: Vec<SpatialMotion>, pub joint_momenta: Vec<SpatialForce>, pub world_joint_momenta: Vec<SpatialForce>, pub joint_forces: Vec<SpatialForce>, pub world_joint_forces: Vec<SpatialForce>, pub tau: Configuration, pub ddq: Configuration, pub jacobian: Jacobian, pub world_inertias: Vec<Inertia>, pub composite_inertias: Vec<Inertia>,
}
Structure containing the mutable properties of the robot.

Fields

joint_data: Vec<JointDataWrapper>

The data of the joints

joint_placements: Vec<SE3>

The placements of the joints in the world frame (oMi)

frame_placements: Vec<SE3>

Placements of the frames in the world frame (oMf)

local_joint_placements: Vec<SE3>

The local joint placements in the parent frame (liMi)

joint_velocities: Vec<SpatialMotion>

Velocities of the joints in the local frame (v)

world_joint_velocities: Vec<SpatialMotion>

Velocities of the joints in the world frame (ov)

joint_accelerations: Vec<SpatialMotion>

Accelerations of the joints in the local frame (a)

joint_accelerations_gravity_field: Vec<SpatialMotion>

Accelerations of the joints due to the gravity field (a_gf)

world_accelerations_gravity_field: Vec<SpatialMotion>

Accelerations of the joints in the world frame including the gravity field (oa_gf)

joint_momenta: Vec<SpatialForce>

The spatial momenta of the joint in the local frame (h), inertia times velocity

world_joint_momenta: Vec<SpatialForce>

The spatial momenta of the joint in the world frame (oh), inertia times velocity

joint_forces: Vec<SpatialForce>

The spatial forces of the joint in the local frame (f), inertia times acceleration plus the Coriolis term

world_joint_forces: Vec<SpatialForce>

The spatial forces of the joint in the world frame (of), inertia times acceleration plus the Coriolis term

tau: Configuration

The configuration of torques/forces applied to the joints (tau)

ddq: Configuration

The joint accelerations of the joints computed by the forward dynamics (ddq)

jacobian: Jacobian

The Jacobian matrix of the joint placements (J)

world_inertias: Vec<Inertia>

The rigid body inertia of the joints in the world frame (oinertias)

composite_inertias: Vec<Inertia>

The composite rigid body inertia of the joints in the world frame (oYcrb)

Implementations

Source

impl Data

pub fn from_joints_data( joint_data: Vec<JointDataWrapper>, model: &Model, ) -> Data

Creates a new Data object from the given joint datas and model.

Arguments
  • joint_data - A vector of joint data wrappers.
  • model - The robot model.
Returns

A new Data object.