pub struct Data {
pub joint_data: Vec<JointDataWrapper>,
pub joint_placements: Vec<SE3>,
pub frame_placements: Vec<SE3>,
pub local_joint_placements: Vec<SE3>,
pub joint_velocities: Vec<SpatialMotion>,
pub joint_accelerations: Vec<SpatialMotion>,
pub joint_accelerations_gravity_free: Vec<SpatialMotion>,
pub joint_momenta: Vec<SpatialForce>,
pub joint_forces: Vec<SpatialForce>,
pub tau: Configuration,
}Expand description
Structure containing the mutable properties of the robot.
Fields
joint_data: Vec<JointDataWrapper>The data of the joints
joint_placements: Vec<SE3>The placements of the joints in the world frame (oMi)
frame_placements: Vec<SE3>Placements of the frames in the world frame (oMf)
local_joint_placements: Vec<SE3>The local joint placements in the parent frame (liMi)
joint_velocities: Vec<SpatialMotion>Velocities of the joints in the world frame (v)
joint_accelerations: Vec<SpatialMotion>Accelerations of the joints in the world frame (a)
joint_accelerations_gravity_free: Vec<SpatialMotion>Accelerations of the joints in the world frame without gravity (a_gf)
joint_momenta: Vec<SpatialForce>The spatial momenta of the joint in the local frame (h), inertia times velocity
joint_forces: Vec<SpatialForce>The spatial forces of the joint in the local frame (f), inertia times acceleration plus the Coriolis term
tau: ConfigurationThe configuration of torques/forces applied to the joints (tau)
Implementations